# Nessus Scan
*<!--{{ HOST_START }}--> - <!--{{ HOST_END }}-->*

**IP:** <!--{{ host_ip }}-->  
**NetBIOS Name:** <!--{{ netbios_name|default:"n/a" }}-->  
**OS:** <!--{{ operating_system|default:"n/a" }}-->

## Vulnerability overview

<!--{% include "vuln-table.md" %}-->
